### MMGen version 0.9.7 Release Notes

#### New features:

  - Monero wallet syncing utility (258651a)
  - mmgen-tool listaddresses: add `show_age`,`show_days` options (f7e54cc)

This release closes a serious exploit (6b9df0e). Upgrading is advised. In
particular, the **offline** MMGen installation in an online/offline setup should
be upgraded.
